<?php

/*
 *      Copyright 2010 Henrik Lennartsson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */


if( !isset($gCms) ) exit;

global $gCms;
$db =& $gCms->GetDB();

$this->SetPreference('visual_framework', (string) $params['input_visual_framework']);
$this->SetPreference('buggy_gmp', (int) $params['input_buggy_gmp']);
$this->SetPreference('use_insecure_rand', (int) $params['input_insecure_rand']);
$this->SetPreference('ca_file_override', (int) $params['input_ca_file_override']);
$this->SetPreference('enable_debugging', (int) $params['input_debugging']);
$this->SetPreference('facebook_app_id', (string) $params['input_facebook_app_id']);
$this->SetPreference('facebook_app_secret', (string) $params['input_facebook_app_secret']);
$this->SetPreference('twitter_consumer_key', (string) $params['input_twitter_consumer_key']);
$this->SetPreference('twitter_consumer_secret', (string) $params['input_twitter_consumer_secret']);
$this->SetPreference('login_redirect', (string) $params['input_login_redirect']);
$this->SetPreference('login_redirect_pageid', (string) $params['input_login_redirect_pageid']);

include(dirname(__FILE__) . '/action.defaultadmin.php');

?>